@@ -20,7 +20,7 @@
 from ConfigParser import ConfigParser
 
 # Import lots of stuff so it's here before chrooting.
-import socket, os, sys, SocketServer, re, stat, os.path, UserDict, xreadlines, tempfile
+import socket, os, sys, SocketServer, re, stat, os.path, UserDict, tempfile
 import time, atexit
 
 from pygopherd import handlers, protocols, GopherExceptions, logger, sighandlers
